# artifician.processors package

## artifician.processors.mapper module

::: {.automodule members="" undoc-members="" show-inheritance=""}
artifician.processors.mapper
:::

## artifician.processors.normalizer module

::: {.automodule members="" undoc-members="" show-inheritance=""}
artifician.processors.normalizer
:::

## artifician.processors.processor module

::: {.automodule members="" undoc-members="" show-inheritance=""}
artifician.processors.processor
:::

## Module contents

::: {.automodule members="" undoc-members="" show-inheritance=""}
artifician.processors
:::
